# Pyntor::Slides - Display slides
# Copyright (C) 2004 Josef Spillner <josef@coolprojects.org>
# Published under GNU GPL conditions

import pygame
from pygame.locals import *
import sys
import time
import random
import os, pwd
import re

def run(slideshow):
	""" Screen setup """

	screen = pygame.display.get_surface()

	screenorig = pygame.Surface((screen.get_width(), screen.get_height()))
	screenorig.blit(screen, (0, 0))

	white = pygame.Surface((screen.get_width(), screen.get_height()))
	white.fill((255, 255, 255))
	alphapart = 160
	for i in range(0, alphapart, 5):
		white.set_alpha(i)
		screen.blit(screenorig, (0, 0))
		screen.blit(white, (0, 0))
		pygame.display.flip()

	screencopy = pygame.Surface((screen.get_width(), screen.get_height()))
	screencopy.blit(screen, (0, 0))

	surface = pygame.Surface((screen.get_width(), screen.get_height()))

	pygame.event.clear()

	titlefont = pygame.font.SysFont("Vera Sans", 60)
	bigfont = pygame.font.SysFont("Vera Sans", 42)
	smallfont = pygame.font.SysFont("Vera Sans", 24)

	""" Read in slide file """

	f = open(slideshow)
	blines = f.readlines()
	f.close()
	lines = []
	for line in blines:
		lines.append(unicode(line.rstrip(), "utf-8"))

	readslide = 1
	oldslide = 0
	mouse = 0

	while 1:
		""" Control """

		pygame.event.pump()
		event = pygame.event.poll()
		if event.type == KEYDOWN:
			key = event.key
			if key == K_ESCAPE or pygame.event.peek(QUIT):
				break
			if key == K_RETURN:
				readslide = oldslide + 1
			if key == K_BACKSPACE:
				readslide = oldslide - 1
			if key == K_f:
				mouse = 1 - mouse
				pygame.mouse.set_visible(mouse)
				pygame.display.toggle_fullscreen()
			if key == K_s:
				pygame.image.save(screen, "static/slide" + str(oldslide) + ".bmp")
			if key == K_PLUS:
				alphapart += 5
				white.set_alpha(alphapart)
				screencopy.blit(screenorig, (0, 0))
				screencopy.blit(white, (0, 0))
				readslide = oldslide
			if key == K_MINUS:
				alphapart -= 5
				white.set_alpha(alphapart)
				screencopy.blit(screenorig, (0, 0))
				screencopy.blit(white, (0, 0))
				readslide = oldslide

		if readslide:
			heading = ""
			subheading = ""
			pageheading = ""
			counter = 1
			rawmode = 0
			rawlist = []

			oldline = ""
			for l in lines:
				if l.find("======") != -1:
					heading = oldline
				if oldline.find("======") != -1:
					subheading = l
				if readslide > 1:
					if l.find("-----") != -1:
						counter += 1
						if counter == readslide:
							pageheading = oldline
							rawmode = 1
						else:
							rawmode = 0
				oldline = l

				if rawmode == 1:
					rawlist.append(l)

			surface.blit(screencopy, (0, 0))

			if readslide == 1:
				f = titlefont.render(heading, 1, (255, 0, 0))
				surface.blit(f, ((surface.get_width() - f.get_width()) / 2, 200))
				f = smallfont.render(subheading, 1, (0, 0, 0))
				surface.blit(f, ((surface.get_width() - f.get_width()) / 2, 300))
			else:
				if len(rawlist) == 0:
					break

				f = bigfont.render(pageheading, 1, (0, 0, 250))
				surface.blit(f, (50, 50))

				i = 0
				rawlist.pop()
				rawlist.pop(0)
				for l in rawlist:
					reimg = re.compile("\[img:(\S+)\]")
					m1 = reimg.match(l)
					reurl = re.compile("\[url:(\S+)\]")
					m2 = reurl.match(l)
					if m1:
						img = m1.group(1)
						pic = pygame.image.load(img)
						surface.blit(pic, (50, 100 + i * 30))
						i += pic.get_height() / 30 + 1
					elif m2:
						url = m2.group(1)
						smallfont.set_italic(1)
						f = smallfont.render(url, 1, (0, 0, 150))
						smallfont.set_italic(0)
						surface.blit(f, (50, 100 + i * 30))
						i += 1
					else:
						f = smallfont.render(l, 1, (0, 0, 0))
						surface.blit(f, (50, 100 + i * 30))
						i += 1

				f = smallfont.render(subheading + " (" + str(readslide) + ")", 1, (0, 0, 0))
				surface.blit(f, (50, 700))

			oldslide = readslide
			readslide = 0

			screen.blit(surface, (0, 0))
			pygame.display.flip()

	#screen.blit(screencopy, (0, 0))
	#pygame.display.flip()

